@@ -138,6 +138,7 @@ def main():
                         choices = [ 'none',
                                     'win11', 'win23', 'win+rom23',
                                     'uefi11', 'uefi23', 'uefi+rom23',
+                                    'redhat', 'redhat+rom',
                                     'all' ],
                         default = 'all',
                         help = 'choose microsoft db keys to enroll')
@@ -233,7 +234,7 @@ def main():
 
     if options.append_boot_filepath:
         for item in options.append_boot_filepath:
-            strings = item.replace('/', '\\').split(' ')
+            strings = item.replace('/', '\\').split(' ', 1)
             filepath = strings[0]
             if len(strings) > 1:
                 optdata = bytes(ucs16.from_string(strings[1]))
